
# title: 'Conflict adaptation'
# subtitle: 'Code for all analyses and graphs in the above-named paper'
# authors: 'Varvara Kuz, Fangzhou Cai, Keyue Chen, Jiaxin Chen, Xuzi Qi, Clement Veall, Yuanqi Zheng,Zhengping Xu, Andrea Santi'
# date: 'August 2023'

# The script provides all the code to perform analyses needed for Experiments 1-4 in the above-named paper. 
# For more information on the analysis steps refer to the methods section of the paper.
# The raw data files for each experiment have the following structure:
  # event.index: event order presentation as completed by participants
  # Participant.Private.ID: unique participant ID attributed by Gorilla
  # Spreadsheet: #list participant was attributed to
  # Screen.Name: name of task (Sentence, Stroop, Question)
  # Reaction.Time: raw reaction time that is used to create RRT (residualised over word length) - continuous
  # Response: response selected by participants (yes/no for questions, yellow/green/blue for Stroop; for SPR shows the word the participant saw before pressing space bar)
  # Attempt: order in which each word appeared in a sentence (always displays 1 for Stroop and Question)
  # Correct: response accuracy for comprehension questions and Stroop (0 by default for each word) - binomial (1 or 0)
  # Timed.Out: Stroop trials on which response wasn't given in the 1500 ms timeframe
  # Condition: indicated one of 8 experimental conditions (A-H) or filler condition (X)
  # Item: experimental and filler item ID (1-126) - randomised for each participant
  # Ambiguity: ambiguous (A) or unambiguous (U) sentences
  # Stroop: congruent (C) or incongruent (I) Stroop trials
  # QT:exp.1-3 comprehension question targeting the main clause (MC) or relative clause (RC) (manipulated in experiment 3 only)
  # Sentence: sentence the participant read
  # Question: question that participant responded to
  # StroopStimulus: 12 types of Stroop pairings (colour+response: e.g. GreenRed.png) - only used in random effects for Stroop RT model
  # TRIAL: experimental and filler item order (exp1:1-126)
  # Exp.Item.TRIAL: gives separate order for fillers and experimental items - fillers get filtered later on so only exp. item order remains


#Load libraries
library(tidyverse)
library(lmerTest)
library(emmeans)
library(MASS) #for contr sdif
options(scipen=999)

#### 1. Experiment 1 ####
#load raw dataset
raw_data_exp1 <- read.csv("~raw_data_exp1.csv", header = TRUE)

# 1.1 Clean up data set --------------------------------------------------------------------------

## 1.1.1set correct variable types
cols<-c('Participant.Private.ID','Spreadsheet','Screen.Name','Attempt','Condition','Item','Ambiguity','Stroop','StroopStimulus' )
raw_data_exp1[cols]<-lapply(raw_data_exp1[cols],as.factor)

cols<-c('Reaction.Time','Correct','TRIAL','Exp.Item.TRIAL')
raw_data_exp1[cols]<-lapply(raw_data_exp1[cols], as.numeric)


## 1.1.2exclude first word of every sentence:
lists_df<-filter(raw_data_exp1,!(Screen.Name=='Sentence'& Attempt=='1'))

# 1.2 Perform the necessary exclusions  --------------------------------------------------------------------------

## 1.2.1 exclude participants who scored <80% (rounded to nearest %) on Stroop trials and filler comp. questions
lists_over80<-lists_df%>% group_by(Participant.Private.ID,Screen.Name)%>%dplyr::mutate(mean_corr=mean(Correct))%>%ungroup()%>% group_by(Participant.Private.ID)%>%
  filter(!any(Screen.Name=='Stroop'& mean_corr<0.795))%>%ungroup()%>%group_by(Participant.Private.ID,Screen.Name,Condition)%>%
  dplyr::mutate(mean_corr=mean(Correct))%>%ungroup()%>%group_by(Participant.Private.ID)%>%
  filter(!any(Screen.Name=='Question'&Condition=='X'&mean_corr<0.795))%>%ungroup()%>% subset(select= -mean_corr)
### calculate number of participants excluded
length(unique(lists_df$Participant.Private.ID))-length(unique(lists_over80$Participant.Private.ID))
### transform into main df
lists_df<-lists_over80
rm(lists_over80)
### calculate number of participants per list
aggregate(lists_df$Participant.Private.ID,list(value = lists_df$Spreadsheet), function(x) length(unique(x)))

## 1.2.2 Exclude sentences with total RT>20000 ms ('Content End' gives us cumulative RT for the whole sentence)
lists_nolongsentences<-lists_df%>%group_by(Participant.Private.ID,Item)%>%filter(!any(Response=='Content End'&Reaction.Time>20000))%>%(ungroup)
### calculate number of trials excluded
sum(lists_df$Response=='Content End')-sum(lists_nolongsentences$Response=='Content End')
### calculate % of trials excluded
(sum(lists_df$Response=='Content End')-sum(lists_nolongsentences$Response=='Content End'))/sum(lists_df$Response=='Content End')*100
### filter out 'Content End' RT & transform into main df
lists_df<-lists_nolongsentences%>%filter(!(Response=='Content End'))
rm(lists_nolongsentences)

## 1.2.3 Exclude words with RTs >100ms and <2000ms
lists_noshortlongwords <- filter(lists_df, !((lists_df$Screen.Name=="Sentence" & lists_df$Reaction.Time<100)|(lists_df$Screen.Name=="Sentence" & lists_df$Reaction.Time>2000.0000)))
###calculate % of words excluded
((sum(lists_df$Screen.Name=='Sentence') - sum(lists_noshortlongwords$Screen.Name=='Sentence'))/sum(lists_df$Screen.Name=='Sentence'))*100
### transform into main df
lists_df <- lists_noshortlongwords 
rm(lists_noshortlongwords)

# 1.3 Create new variable 'region' for sentence regions --------------------------------------------------------------------------
lists_df$region <- ifelse(lists_df$Attempt %in% c("2", "3"), 'Subject', 
                          ifelse(lists_df$Attempt %in% c("4", "5") & lists_df$Condition %in% c("B", "D"), 'Relativizer', 
                                 ifelse(lists_df$Attempt %in% c( "6", "7", "8", "9") &  lists_df$Condition %in% c("B", "D"), 'Ambig Region', 
                                        ifelse(lists_df$Attempt %in% c("4", "5", "6", "7") & lists_df$Condition  %in% c("A", "C"), 'Ambig Region', 
                                               ifelse(lists_df$Attempt %in% c("10", "11", "12") & lists_df$Condition %in% c("B","D"), 'Disambig Region', 
                                                      ifelse(lists_df$Attempt %in% c("8", "9", "10") & lists_df$Condition %in% c("A", "C"), 'Disambig Region', 
                                                             ifelse(lists_df$Attempt %in% c("13") & lists_df$Condition %in% c("B", "D"), 'Spill', 
                                                                    ifelse(lists_df$Attempt %in% c("11") & lists_df$Condition %in% c("A", "C"), 'Spill', 'other'))))))))


lists_df$region <- as.factor(lists_df$region)

# 1.4 Create RRT and then exclude the fillers --------------------------------------------------------------------------

## 1.4.1 calculate residual reading times (RRTs): regress log RTs over Nchar with linear mixed effects regression
### create new variable 'nchar'(number of characters) for all words (exp +fillers)
lists_df$LetterNumbers <- nchar(lists_df$Response, type="chars", allowNA=FALSE)

### create new df with sentences only (exclude question and Stroop)
lists_sentences <- filter(lists_df, (lists_df$Screen.Name=="Sentence"))

### run RlogRT model
RRT_model <- lmer(log(Reaction.Time) ~ scale(LetterNumbers) + (1|Participant.Private.ID), lists_sentences)
lists_sentences$RRT <- residuals(RRT_model)

## 1.4.2 Exclude Filler
lists_sentences <- filter(lists_sentences, !((lists_sentences$Condition=="X")))


# 1.5 Graphs --------------------------------------------------------------------------

## 1.5.1 Stroop by Ambiguity interaction at ambiguous region
ambig_reg_plot<-lists_sentences%>%filter(region=='Ambig Region')%>%
  group_by(Ambiguity, Stroop)%>%
  summarise(N=length(RRT[!is.na(RRT)]),
            mean = mean(RRT, na.rm=T), sd = sd(RRT, na.rm=T),
            se= sd(RRT, na.rm=T)/sqrt(length(RRT[!is.na(RRT)])))%>%ungroup
confidence_intervals <- qt(0.95/2 + .5, ambig_reg_plot$N-1)
ambig_reg_plot$conf_int <- ambig_reg_plot$se * confidence_intervals
ggplot(ambig_reg_plot, aes(Stroop, mean, group = Ambiguity, colour = Ambiguity, fill = Ambiguity, shape = Ambiguity, linetype = Ambiguity)) + geom_point(position=position_dodge(0.05)) + geom_line(size=1.4) + geom_errorbar(aes(ymin=mean-conf_int, ymax=mean+conf_int), width=0.2,position=position_dodge(0.05)) + labs(x = 'Stroop trial type', y = 'Residual log RTs(ms)', colour = 'Ambiguity', shape = 'Ambiguity', linetype = 'Ambiguity')

## 1.5.2 Stroop by Ambiguity interaction at disambiguating region
disambig_reg_plot<-lists_sentences%>%filter(region=='Disambig Region')%>%
  group_by(Ambiguity, Stroop)%>%
  summarise(N=length(RRT[!is.na(RRT)]),
            mean = mean(RRT, na.rm=T), sd = sd(RRT, na.rm=T),
            se= sd(RRT, na.rm=T)/sqrt(length(RRT[!is.na(RRT)])))%>%ungroup
confidence_intervals <- qt(0.95/2 + .5, disambig_reg_plot$N-1)
disambig_reg_plot$conf_int <- disambig_reg_plot$se * confidence_intervals
ggplot(disambig_reg_plot, aes(Stroop, mean, group = Ambiguity, colour = Ambiguity, fill = Ambiguity, shape = Ambiguity, linetype = Ambiguity)) + geom_point(position=position_dodge(0.05)) + geom_line(size=1.4) + geom_errorbar(aes(ymin=mean-conf_int, ymax=mean+conf_int), width=0.2,position=position_dodge(0.05)) + labs(x = 'Stroop trial type', y = 'Residual log RTs(ms)', colour = 'Ambiguity', shape = 'Ambiguity', linetype = 'Ambiguity')

## 1.5.3 Syntactic adaptation effect at disambiguating region
### regress RRT over log(TRIAL) to adjust for trial order (log(TRIAL) will be included in final model)
synt_adaptation_model <- lm(RRT ~ (log(TRIAL)), lists_sentences)
lists_sentences$RRT_Exp.Item <- residuals(synt_adaptation_model)

### use the residuals to plot them against exp.item trial order. Trend is summarised loglinearly
synt_adaptation_plot<-lists_sentences%>%filter(region=='Disambig Region')%>%
  group_by(Exp.Item.TRIAL,Ambiguity)%>%
  summarise(N=length(RRT_Exp.Item [!is.na(RRT_Exp.Item )]),
            mean = mean(RRT_Exp.Item , na.rm=T), sd = sd(RRT_Exp.Item , na.rm=T),
            se= sd(RRT_Exp.Item , na.rm=T)/sqrt(length(RRT_Exp.Item [!is.na(RRT_Exp.Item)])))%>%ungroup
ggplot(synt_adaptation_plot, aes(Exp.Item.TRIAL, mean, group = Ambiguity, colour = Ambiguity, fill = Ambiguity, shape = Ambiguity, linetype = Ambiguity)) + geom_point() + guides(fill=FALSE) + geom_smooth(method = lm, formula = y ~  log(x)) + labs(x = 'Experimental item trial', y = 'Log RTs corrected for length and order(ms)', colour = 'Ambiguity', shape = 'Ambiguity', linetype = 'Ambiguity')

# 1.6 Stroop RT model --------------------------------------------------------------------------

## 1.6.1 create new df with only Stroop RTs
stroop_model<-lists_df%>% filter(Screen.Name=="Stroop")%>%
  mutate(Timed.Out=replace_na(Timed.Out,0))%>%filter(!(Timed.Out=='1'))

## 1.6.2 Define function to centre around mean to reduce collinearity (used for TRIAL and exp. item trial variables for all models)
c. <- function (x) scale(x, scale = FALSE)

## 1.6.3 Set contrasts
stroop_model$Stroop<-factor(stroop_model$Stroop)
contrasts(stroop_model$Stroop) <- contr.sum
contrasts(stroop_model$Stroop)

## 1.6.4 Run model
model1 <- lmer(Reaction.Time ~ Stroop+c.(log(TRIAL))+(1+Stroop| Participant.Private.ID)+(1|StroopStimulus), stroop_model, control = lmerControl(optCtrl = list(maxfun = 1e5)))
summary(model1)

# 1.7 Ambiguous region RRT model --------------------------------------------------------------------------

## 1.7.1 create new df with mean RRTs for sub verb region
ambig_reg_corrected<-lists_sentences%>%filter(region=='Ambig Region')%>%
  group_by(Ambiguity, Stroop, Participant.Private.ID, Item, Exp.Item.TRIAL, TRIAL)%>%
  summarise(mean_corr_lrt = mean(RRT, na.rm=T))%>%ungroup()

## 1.7.2 Set contrasts
ambig_reg_corrected$Ambiguity <- factor(ambig_reg_corrected$Ambiguity)
contrasts(ambig_reg_corrected$Ambiguity) <- "contr.sum"
contrasts(ambig_reg_corrected$Ambiguity)

contrasts(ambig_reg_corrected$Stroop) <- "contr.sum"
contrasts(ambig_reg_corrected$Stroop)

## 1.7.3 Run model
model1 <- lmer(mean_corr_lrt ~ Ambiguity*Stroop*c.(Exp.Item.TRIAL)+c.(log(TRIAL)) +(1| Participant.Private.ID) + (1+Ambiguity| Item), ambig_reg_corrected, control = lmerControl(optCtrl = list(maxfun = 1e5)))
summary(model1)

##1.7.4 simple effects analysis
emm_model1<-emmeans(model1, ~Ambiguity|Stroop,pbkrtest.limit = 3438)
pairs(emm_model1)

emm_model1<-emmeans(model1, ~Stroop|Ambiguity,pbkrtest.limit = 3438)
pairs(emm_model1)

# 1.8 Disambiguating region RRT model --------------------------------------------------------------------------

## 1.8.1 create new df with mean RRTs disambiguating region
disambig_reg_corrected<-lists_sentences%>%filter(region=='Disambig Region')%>%
  group_by(Ambiguity, Stroop, Participant.Private.ID, Item, Exp.Item.TRIAL, TRIAL)%>%
  summarise(mean_corr_lrt = mean(RRT, na.rm=T))%>%ungroup()

## 1.8.2 Set contrasts
disambig_reg_corrected$Ambiguity <- factor(disambig_reg_corrected$Ambiguity)
contrasts(disambig_reg_corrected$Ambiguity) <- "contr.sum"
contrasts(disambig_reg_corrected$Ambiguity)

contrasts(disambig_reg_corrected$Stroop) <- "contr.sum"
contrasts(disambig_reg_corrected$Stroop)

## 1.8.3 Run model
model1 <- lmer(mean_corr_lrt ~ Ambiguity*Stroop*c.(Exp.Item.TRIAL) + c.(log(TRIAL))+ (1+Ambiguity| Participant.Private.ID) + (1+Ambiguity+Stroop| Item), disambig_reg_corrected, control = lmerControl(optCtrl = list(maxfun = 1e5)))
summary(model1)


# 1.9 Spill (last word) region RRT model --------------------------------------------------------------------------

## 1.9.1 create new df with mean RRTs ambiguous region
spill_reg_corrected<-lists_sentences%>%filter(region=='Spill')%>%
  group_by(Ambiguity, Stroop, Participant.Private.ID, Item, Exp.Item.TRIAL, TRIAL)%>%
  summarise(mean_corr_lrt = mean(RRT, na.rm=T))%>%ungroup()

## 1.9.2 Set contrasts
spill_reg_corrected$Ambiguity <- factor(spill_reg_corrected$Ambiguity)
contrasts(spill_reg_corrected$Ambiguity) <- "contr.sum"
contrasts(spill_reg_corrected$Ambiguity)

contrasts(spill_reg_corrected$Stroop) <- "contr.sum"
contrasts(spill_reg_corrected$Stroop)

## 1.9.3 Run model
model1 <- lmer(mean_corr_lrt ~ Ambiguity*Stroop*c.(Exp.Item.TRIAL) + c.(log(TRIAL))+ (1+Stroop| Participant.Private.ID) + (1+Ambiguity| Item), spill_reg_corrected, control = lmerControl(optCtrl = list(maxfun = 1e5))) 
summary(model1)

# 1.10 Accuracy model --------------------------------------------------------------------------

## 1.10.1 Create df with question data only and filter out filler items
lists_questions<-lists_df%>%filter(Screen.Name=='Question')%>%filter(!(Condition=="X"))

## 1.10.2 Set 'correct' as factor
lists_questions$Correct<-as.factor(lists_questions$Correct)

## 1.10.3 Set contrasts
lists_questions$Ambiguity<-factor(lists_questions$Ambiguity)
contrasts(lists_questions$Ambiguity) <- "contr.sum"
contrasts(lists_questions$Ambiguity)

contrasts(lists_questions$Stroop) <- "contr.sum"
contrasts(lists_questions$Stroop)

## 1.10.3 Run model
model1 <- glmer(Correct ~ Ambiguity*Stroop*c.(Exp.Item.TRIAL) +(1| Participant.Private.ID)+(1+Ambiguity| Item), lists_questions, family=binomial, glmerControl(optimizer = "bobyqa", optCtrl = list(maxfun = 100000))) 
summary(model1)

## 1.10.4 Simple main effects analysis
test(emtrends(model1, pairwise ~Ambiguity|Stroop, var='Exp.Item.TRIAL'))

# 1.11 Correlation between Stroop and ambiguity effects  --------------------------------------------------------------------------

## 1.11.1 load practice Stroop file
practice_stroop <- read.csv("~practice_stroop_exp1.csv", header = TRUE)
practice_stroop$Reaction.Time<-as.numeric(practice_stroop$Reaction.Time)
practice_stroop$Participant.Private.ID<-as.factor(practice_stroop$Participant.Private.ID)

## 1.11.2 exclude unnecessary rows (fixation, instructions etc), colour patch trials and timed out trials
practice_stroop<-practice_stroop%>%filter((Screen.Name=="Stroop")&(Trial.Type=='StroopPractice')&(Timed.Out=="0"))

## 1.11.3 calculate average ambiguity effect
disambig_reg_effect<-lists_sentences%>%filter(region=='Disambig Region')%>%group_by(Participant.Private.ID)%>%
  summarise(amb_effect=mean(RRT[Ambiguity=='Amb'])-mean(RRT[Ambiguity=='Unamb']))%>%
  subset(select=c('Participant.Private.ID','amb_effect'))%>%ungroup()

## 1.11.4 calculate average Stroop effect
stroop_effect<-practice_stroop%>%group_by(Participant.Private.ID)%>%
  summarise(stroop_effect=mean(Reaction.Time[Trial.Condition=='I'])-mean(Reaction.Time[Trial.Condition=='C']))%>%
  subset(select=c('Participant.Private.ID','stroop_effect'))%>%ungroup()

## 1.11.5 merge the two dataframes and exclude any 'NA' for ambiguity_eff - these will be the same ones excluded from main dataframe
correlation<-stroop_effect%>%left_join(disambig_reg_effect, by='Participant.Private.ID')%>% na.exclude

## 1.11.6 perform correlation
cor.test(correlation$amb_effect,correlation$stroop_effect)

## 1.11.7 calculate mean and SD for each effect
sd(correlation$amb_effect)
mean(correlation$amb_effect)

sd(correlation$stroop_effect)
mean(correlation$stroop_effect)

#### 2. Experiment 2 ####
rm(list=ls())

#load raw dataset
raw_data_exp2 <- read.csv("~raw_data_exp2.csv", header = TRUE)

# 2.1 Clean up data set --------------------------------------------------------------------------

## 2.1.1 Set correct variable types
cols<-c('Participant.Private.ID','Spreadsheet','Screen.Name','Attempt','Condition','Item','Ambiguity','Stroop','StroopStimulus' )
raw_data_exp2[cols]<-lapply(raw_data_exp2[cols],as.factor)

cols<-c('Reaction.Time','Correct','TRIAL','Exp.Item.TRIAL')
raw_data_exp2[cols]<-lapply(raw_data_exp2[cols], as.numeric)

## 2.1.2exclude first word of every sentence:
lists_df<-filter(raw_data_exp2,!(Screen.Name=='Sentence'& Attempt=='1'))

# 2.2 Perform the necessary exclusions --------------------------------------------------------------------------

## 2.2.1 exclude participants who scored <80% (to the nearest %) on Stroop trials and filler comp. questions
lists_over80<-lists_df%>% group_by(Participant.Private.ID,Screen.Name)%>%dplyr::mutate(mean_corr=mean(Correct))%>%ungroup()%>% group_by(Participant.Private.ID)%>%
  filter(!any(Screen.Name=='Stroop'& mean_corr<0.795))%>%ungroup()%>%group_by(Participant.Private.ID,Screen.Name,Condition)%>%
  dplyr::mutate(mean_corr=mean(Correct))%>%ungroup()%>%group_by(Participant.Private.ID)%>%
  filter(!any(Screen.Name=='Question'&Condition=='X'&mean_corr<0.795))%>%ungroup()%>% subset(select= -mean_corr)
### calculate number of participants excluded
length(unique(lists_df$Participant.Private.ID))-length(unique(lists_over80$Participant.Private.ID))
### transform into main df
lists_df<-lists_over80
rm(lists_over80)
### calculate number of participants per list
aggregate(lists_df$Participant.Private.ID,list(value = lists_df$Spreadsheet), function(x) length(unique(x)))

## 2.2.2 Exclude sentences with total RT>20000 ms ('Content End' gives us cumulative RT for the whole sentence)
lists_nolongsentences<-lists_df%>%group_by(Participant.Private.ID,Item)%>%filter(!any(Response=='Content End'&Reaction.Time>20000))%>%(ungroup)
### calcute number of sentences excluded
sum(lists_df$Response=='Content End')-sum(lists_nolongsentences$Response=='Content End')
### calculate % of sentence excluded
(sum(lists_df$Response=='Content End')-sum(lists_nolongsentences$Response=='Content End'))/sum(lists_df$Response=='Content End')*100
### filter out 'Content End' RT & transform into main df
lists_df<-lists_nolongsentences%>%filter(!(Response=='Content End'))
rm(lists_nolongsentences)

## 2.2.3 Exclude words with RTs >100ms and <2000ms
lists_noshortlongwords <- filter(lists_df, !((lists_df$Screen.Name=="Sentence" & lists_df$Reaction.Time<100)|(lists_df$Screen.Name=="Sentence" & lists_df$Reaction.Time>2000.0000)))
### calculate % of words excluded
((sum(lists_df$Screen.Name=='Sentence') - sum(lists_noshortlongwords$Screen.Name=='Sentence'))/sum(lists_df$Screen.Name=='Sentence'))*100
### transform into main df
lists_df <- lists_noshortlongwords 
rm(lists_noshortlongwords)

# 2.3 Create new variable 'region' for sentence regions --------------------------------------------------------------------------
lists_df$region <- ifelse(lists_df$Attempt %in% c("2", "3"), 'Subject', 
                          ifelse(lists_df$Attempt %in% c("4", "5") & lists_df$Condition %in% c("B", "D", "F"), 'Relativizer', 
                                 ifelse(lists_df$Attempt %in% c( "6", "7", "8", "9") &  lists_df$Condition %in% c("B", "D", "F"), 'Ambig Region', 
                                        ifelse(lists_df$Attempt %in% c("4", "5", "6", "7") & lists_df$Condition  %in% c("A", "C", "E"), 'Ambig Region', 
                                               ifelse(lists_df$Attempt %in% c("10", "11", "12") & lists_df$Condition %in% c("B","D", "F"), 'Disambig Region', 
                                                      ifelse(lists_df$Attempt %in% c("8", "9", "10") & lists_df$Condition %in% c("A", "C", "E"), 'Disambig Region', 
                                                             ifelse(lists_df$Attempt %in% c("13") & lists_df$Condition %in% c("B", "D", "F"), 'Spill', 
                                                                    ifelse(lists_df$Attempt %in% c("11") & lists_df$Condition %in% c("A", "C","E"), 'Spill', 'other'))))))))

lists_df$region <- as.factor(lists_df$region)

# 2.4 Create RRT and then exclude the fillers --------------------------------------------------------------------------

## 2.4.1 calculate residual reading times (RRTs): regress log RTs over Nchar with linear mixed effects regression
### create new variable 'nchar'(number of characters) for all words (exp +fillers)
lists_df$LetterNumbers <- nchar(lists_df$Response, type="chars", allowNA=FALSE)
### create new df with sentences only (exclude question and Stroop)
lists_sentences <- filter(lists_df, (lists_df$Screen.Name=="Sentence"))
### run RlogRT model
RRT_model <- lmer(log(Reaction.Time) ~ scale(LetterNumbers) + (1|Participant.Private.ID), lists_sentences)
lists_sentences$RRT <- residuals(RRT_model)

## 2.4.2 Exclude Filler 
lists_sentences <- filter(lists_sentences, !((lists_sentences$Condition=="X")))


# 2.5 Graphs --------------------------------------------------------------------------
## 2.5.1 Stroop effect
# create new df with only Stroop RTs (and exclude times out trials)
stroop_model<-lists_df%>% filter(Screen.Name=="Stroop")%>% mutate(Timed.Out=replace_na(Timed.Out,0))%>%filter(!(Timed.Out=='1'))
#reorder stroop levels to make the comparison easier
stroop_model$Stroop<-factor(stroop_model$Stroop, levels=c('I','N','C'))

stroop_main_plot<-stroop_model%>%group_by(Stroop)%>%
  summarise(N=length(Reaction.Time[!is.na(Reaction.Time)]),
            mean = mean(Reaction.Time, na.rm=T), sd = sd(Reaction.Time, na.rm=T),
            se= sd(Reaction.Time, na.rm=T)/sqrt(length(Reaction.Time[!is.na(Reaction.Time)])))%>%ungroup()
confidence_intervals <- qt(0.95/2 + .5, stroop_main_plot$N-1)
stroop_main_plot$conf_int <- stroop_main_plot$se * confidence_intervals
ggplot(stroop_main_plot, aes(Stroop, mean, group = Stroop, fill=Stroop)) + geom_bar(width=0.2, stat="identity") + geom_errorbar(aes(Stroop,ymin=mean-conf_int, ymax=mean+conf_int), width=0.1) + labs(x = 'Stroop trial type', y = 'Reaction time (ms)')

## 2.5.2 Stroop by ambiguity interaction at disambiguating region
disambig_reg_plot<-lists_sentences%>%filter(region=='Disambig Region')%>%
  group_by(Ambiguity, Stroop)%>%
  summarise(N=length(RRT[!is.na(RRT)]),
            mean = mean(RRT, na.rm=T), sd = sd(RRT, na.rm=T),
            se= sd(RRT, na.rm=T)/sqrt(length(RRT[!is.na(RRT)])))%>%ungroup
confidence_intervals <- qt(0.95/2 + .5, disambig_reg_plot$N-1)
disambig_reg_plot$conf_int <- disambig_reg_plot$se * confidence_intervals
ggplot(disambig_reg_plot, aes(Stroop, mean, group = Ambiguity, colour = Ambiguity, fill = Ambiguity, shape = Ambiguity, linetype = Ambiguity)) + geom_point(position=position_dodge(0.05)) + geom_line(size=1.4) + geom_errorbar(aes(ymin=mean-conf_int, ymax=mean+conf_int), width=0.2,position=position_dodge(0.05)) + labs(x = 'Stroop trial type', y = 'Residual log RTs(ms)', colour = 'Ambiguity', shape = 'Ambiguity', linetype = 'Ambiguity')

## 2.5.3 Syntactic adaptation effect at disambiguating region
### regress RRT over log(TRIAL) to adjust for trial order (log(TRIAL) will be included in final model)
synt_adaptation_model <- lm(RRT ~ (log(TRIAL)), lists_sentences)
lists_sentences$RRT_Exp.Item <- residuals(synt_adaptation_model)

### use the residuals to plot them against exp.item trial order. Trend is summarised loglinearly
synt_adaptation_plot<-lists_sentences%>%filter(region=='Disambig Region')%>%
  group_by(Exp.Item.TRIAL,Ambiguity)%>%
  summarise(N=length(RRT_Exp.Item [!is.na(RRT_Exp.Item )]),
            mean = mean(RRT_Exp.Item , na.rm=T), sd = sd(RRT_Exp.Item , na.rm=T),
            se= sd(RRT_Exp.Item , na.rm=T)/sqrt(length(RRT_Exp.Item [!is.na(RRT_Exp.Item)])))%>%ungroup
ggplot(synt_adaptation_plot, aes(Exp.Item.TRIAL, mean, group = Ambiguity, colour = Ambiguity, fill = Ambiguity, shape = Ambiguity, linetype = Ambiguity)) + geom_point() + guides(fill=FALSE) + geom_smooth(method = lm, formula = y ~  log(x)) + labs(x = 'Experimental item trial', y = 'Log RTs corrected for length and order(ms)', colour = 'Ambiguity', shape = 'Ambiguity', linetype = 'Ambiguity')

# 2.6 Stroop RT model --------------------------------------------------------------------------


## 2.6.2 Define function to centre around mean to reduce collinearity (used for TRIAL and exp. item trial variables for all models)
c. <- function (x) scale(x, scale = FALSE)

## 2.6.3 Set contrasts
stroop_model$Stroop<-factor(stroop_model$Stroop, levels=c('C','I','N')) #set stroop levels to make two contrasts: 1:C-I & 2:I-N
contrasts(stroop_model$Stroop) <- contr.sdif(3)
contrasts(stroop_model$Stroop)

## 2.6.4 Run model
model1 <- lmer(Reaction.Time ~ Stroop+c.(log(TRIAL))+(1| Participant.Private.ID)+(1|StroopStimulus), stroop_model, control = lmerControl(optCtrl = list(maxfun = 1e5)))
summary(model1)

# 2.7 Ambiguous region RRT model --------------------------------------------------------------------------

## 2.7.1 create new df with mean RRTs for sub verb region
ambig_reg_corrected<-lists_sentences%>%filter(region=='Ambig Region')%>%
  group_by(Ambiguity, Stroop, Participant.Private.ID, Item, Exp.Item.TRIAL, TRIAL)%>%
  summarise(mean_corr_lrt = mean(RRT, na.rm=T))%>%ungroup()

## 2.7.2 Set contrasts
ambig_reg_corrected$Ambiguity <- factor(ambig_reg_corrected$Ambiguity)
contrasts(ambig_reg_corrected$Ambiguity) <- "contr.sum"
contrasts(ambig_reg_corrected$Ambiguity)

ambig_reg_corrected$Stroop<-factor(ambig_reg_corrected$Stroop, levels=c('C','I','N'))
contrasts(ambig_reg_corrected$Stroop) <- contr.sdif(3)
contrasts(ambig_reg_corrected$Stroop)

## 2.7.3 Run model

model1 <- lmer(mean_corr_lrt ~ Ambiguity*Stroop*c.(Exp.Item.TRIAL)+c.(log(TRIAL)) +(1+Ambiguity| Participant.Private.ID) + (1+Ambiguity| Item), ambig_reg_corrected, control = lmerControl(optCtrl = list(maxfun = 1e5)))
summary(model1)

# 2.8 Disambiguating region RRT model --------------------------------------------------------------------------

## 2.8.1 create new df with mean RRTs ambiguous region
disambig_reg_corrected<-lists_sentences%>%filter(region=='Disambig Region')%>%
  group_by(Ambiguity, Stroop, Participant.Private.ID, Item, Exp.Item.TRIAL, TRIAL)%>%
  summarise(mean_corr_lrt = mean(RRT, na.rm=T))%>%ungroup()

## 2.8.2 Set contrasts
disambig_reg_corrected$Ambiguity <- factor(disambig_reg_corrected$Ambiguity)
contrasts(disambig_reg_corrected$Ambiguity) <- "contr.sum"
contrasts(disambig_reg_corrected$Ambiguity)

disambig_reg_corrected$Stroop<-factor(disambig_reg_corrected$Stroop, levels=c('C','I','N'))
contrasts(disambig_reg_corrected$Stroop) <- contr.sdif
contrasts(disambig_reg_corrected$Stroop)

## 2.8.3 Run model
model1 <- lmer(mean_corr_lrt ~ Ambiguity*Stroop*c.(Exp.Item.TRIAL)+c.(log(TRIAL)) + (1+Ambiguity| Participant.Private.ID) + (1| Item), disambig_reg_corrected, control = lmerControl(optCtrl = list(maxfun = 1e5)))
summary(model1)

# simple main effects analysis for syntactic adaptation
test(emtrends(model1, pairwise ~Ambiguity, var='Exp.Item.TRIAL',pbkrtest.limit = 6027))

# 2.9 Spill (last word) region RRT model --------------------------------------------------------------------------

##2.9.1 create new df with mean RRTs ambiguous region
spill_reg_corrected<-lists_sentences%>%filter(region=='Spill')%>%
  group_by(Ambiguity, Stroop, Participant.Private.ID, Item, Exp.Item.TRIAL, TRIAL)%>%
  summarise(mean_corr_lrt = mean(RRT, na.rm=T))%>%ungroup()

##2.9.2 Set contrasts
spill_reg_corrected$Ambiguity <- factor(spill_reg_corrected$Ambiguity)
contrasts(spill_reg_corrected$Ambiguity) <- "contr.sum"
contrasts(spill_reg_corrected$Ambiguity)

spill_reg_corrected$Stroop<-factor(spill_reg_corrected$Stroop, levels=c('C','I','N'))
contrasts(spill_reg_corrected$Stroop) <- contr.sdif(3)
contrasts(spill_reg_corrected$Stroop)

##2.9.3 Run model
model1 <- lmer(mean_corr_lrt ~ Ambiguity*Stroop*c.(Exp.Item.TRIAL) + c.(log(TRIAL))+ (1+Ambiguity| Participant.Private.ID) + (1+Ambiguity| Item), spill_reg_corrected, control = lmerControl(optCtrl = list(maxfun = 1e5))) 
summary(model1)

# 2.10 Accuracy model --------------------------------------------------------------------------

## 2.10.1 Create df with question data only and filter out filler items
lists_questions<-lists_df%>%filter(Screen.Name=='Question')%>%filter(!(Condition=="X"))

## 2.10.2 Set 'correct' as factor
lists_questions$Correct<-as.factor(lists_questions$Correct)

## 2.10.2 Set contrast
lists_questions$Ambiguity<-factor(lists_questions$Ambiguity)
contrasts(lists_questions$Ambiguity) <- contr.sum
contrasts(lists_questions$Ambiguity)

lists_questions$Stroop<-factor(lists_questions$Stroop, levels=c('C','I','N'))
contrasts(lists_questions$Stroop) <- contr.sdif
contrasts(lists_questions$Stroop)

## 2.10.3 Run model
model1 <- glmer(Correct ~ Ambiguity*Stroop*c.(Exp.Item.TRIAL)+(1+Ambiguity| Participant.Private.ID)+(1+Ambiguity| Item), lists_questions, family=binomial, glmerControl(optimizer = "bobyqa", optCtrl = list(maxfun = 100000))) 
summary(model1)

# 2.11 Correlation between Stroop and ambiguity effects  --------------------------------------------------------------------------

## 2.11.1 load practice Stroop file
practice_stroop <- read.csv("~practice_stroop_exp2.csv", header = TRUE)
practice_stroop$Reaction.Time<-as.numeric(practice_stroop$Reaction.Time)
practice_stroop$Participant.Private.ID<-as.factor(practice_stroop$Participant.Private.ID)

## 2.11.2 exclude unnecessary rows (fixation, instructions etc), colour patch trials and timed out trials
practice_stroop<-practice_stroop%>%filter((Screen.Name=="Stroop")&(Trial.Type=='StroopPractice')&(Timed.Out=="0"))

## 2.11.3 calculate average ambiguity effect
disambig_reg_effect<-lists_sentences%>%filter(region=='Disambig Region')%>%group_by(Participant.Private.ID)%>%
  summarise(amb_effect=mean(RRT[Ambiguity=='Amb'])-mean(RRT[Ambiguity=='Unamb']))%>%
  subset(select=c('Participant.Private.ID','amb_effect'))%>%ungroup()

## 2.11.4 calculate average Stroop effect
stroop_effect<-practice_stroop%>%group_by(Participant.Private.ID)%>%
  summarise(stroop_effect=mean(Reaction.Time[Trial.Condition=='I'])-mean(Reaction.Time[Trial.Condition=='C']))%>%
  subset(select=c('Participant.Private.ID','stroop_effect'))%>%ungroup()

## 2.11.5 merge the two dataframes and exclude any 'NA' for ambiguity_eff - these will be the same ones excluded from main dataframe
  #excludes ones extra participant (3232525) from main analysis as all trials were timed out (therefore NA for Stroop effect) (but was ok during experiment)
correlation<-stroop_effect%>%left_join(disambig_reg_effect, by='Participant.Private.ID')%>% na.exclude

## 2.11.6 perform correlation
cor.test(correlation$amb_effect,correlation$stroop_effect)

## 2.11.7 calculate mean and SD for each effect
sd(correlation$amb_effect)
mean(correlation$amb_effect)

sd(correlation$stroop_effect)
mean(correlation$stroop_effect)

#### 3. Experiment 3 ####
rm(list=ls())

#load raw dataset
raw_data_exp3 <- read.csv("~raw_data_exp3.csv", header = TRUE)

# 3.1 Clean up data set --------------------------------------------------------------------------

## 3.1.1 Set correct variable types
cols<-c('Participant.Private.ID','Spreadsheet','Screen.Name','Condition','Item','Ambiguity','Stroop','StroopStimulus' )
raw_data_exp3[cols]<-lapply(raw_data_exp3[cols],as.factor)

cols<-c('Reaction.Time','Correct','TRIAL','Exp.Item.TRIAL')
raw_data_exp3[cols]<-lapply(raw_data_exp3[cols], as.numeric)



## 3.1.2 transform into lists_df (no need to exclude 1st word as full sentence presentation):
lists_df<-raw_data_exp3


# 3.2 Perform the necessary exclusions --------------------------------------------------------------------------

## 3.2.1 exclude participants who scored <80% (to the nearest %) on Stroop trials and filler comp. questions
lists_over80<-lists_df%>% group_by(Participant.Private.ID,Screen.Name)%>%dplyr::mutate(mean_corr=mean(Correct))%>%ungroup()%>% group_by(Participant.Private.ID)%>%
  filter(!any(Screen.Name=='Stroop'& mean_corr<0.795))%>%ungroup()%>%group_by(Participant.Private.ID,Screen.Name,Condition)%>%
  dplyr::mutate(mean_corr=mean(Correct))%>%ungroup()%>%group_by(Participant.Private.ID)%>%
  filter(!any(Screen.Name=='Question'&Condition=='X'&mean_corr<0.795))%>%ungroup()%>% subset(select= -mean_corr)
### calculate number of participants excluded
length(unique(lists_df$Participant.Private.ID))-length(unique(lists_over80$Participant.Private.ID))
### transform into main df
lists_df<-lists_over80
rm(lists_over80)
### calculate number of participants per list
aggregate(lists_df$Participant.Private.ID,list(value = lists_df$Spreadsheet), function(x) length(unique(x)))

## 3.2.2 Exclude any trials with sentences with log RTs>2.5 SD (over each item)
lists_df<-lists_df%>%group_by(Screen.Name,Item)%>%dplyr::mutate(mean_by_item=mean(log(Reaction.Time)))%>%dplyr::mutate(sd_by_item=sd(log(Reaction.Time)))%>%dplyr::mutate(SD_eachitem=(log(Reaction.Time)-mean_by_item)/sd_by_item)%>% ungroup()
lists_short <- lists_df %>% group_by(Participant.Private.ID,Item) %>% filter(!any(SD_eachitem<(-2.5)&Screen.Name=='Sentence')) %>% ungroup()

### calculate number of sentences excluded
sum(lists_df$Screen.Name=='Sentence')-sum(lists_short$Screen.Name=='Sentence')

### calculate % of sentence excluded
(sum(lists_df$Screen.Name=='Sentence')-sum(lists_short$Screen.Name=='Sentence'))/sum(lists_df$Screen.Name=='Sentence')*100

### transform into main df
lists_df<-lists_short

# 3.3 Create RRT and then exclude the fillers --------------------------------------------------------------------------

## 3.3.1 calculate residual reading times (RRTs): regress log RTs over Nchar with linear mixed effects regression
### create new variable 'nchar'(number of characters) for all words (exp +fillers)
lists_df$Sentence_nospace<-gsub(" ","",lists_df$Sentence)
lists_df$LetterNumbers <- nchar(lists_df$Sentence_nospace, type="chars", allowNA=FALSE)

### create new df with sentences only (exclude question and Stroop)
lists_sentences <- filter(lists_df, (lists_df$Screen.Name=="Sentence"))
### run RlogRT model
RRT_model <- lmer(log(Reaction.Time) ~ scale(LetterNumbers) + (1+scale(LetterNumbers)|Participant.Private.ID), lists_sentences)
lists_sentences$RRT <- residuals(RRT_model)

## 3.3.2 Exclude Filler 
lists_sentences <- filter(lists_sentences, !((lists_sentences$Condition=="X")))

# 3.4 Graphs --------------------------------------------------------------------------

## 3.4.1 Syntactic adaptation effect for full sentence
### regress RRT over log(TRIAL) to adjust for length (log(TRIAL) will be included in final model)
synt_adaptation_model <- lm(RRT ~ (log(TRIAL)), lists_sentences)
lists_sentences$RRT_Exp.Item <- residuals(synt_adaptation_model)
### use the residuals to plot them against exp.item trial order. Trend is summarised loglinearly
synt_adaptation_plot<-lists_sentences%>%
  group_by(Exp.Item.TRIAL,Ambiguity)%>%
  summarise(N=length(RRT_Exp.Item [!is.na(RRT_Exp.Item )]),
            mean = mean(RRT_Exp.Item , na.rm=T), sd = sd(RRT_Exp.Item , na.rm=T),
            se= sd(RRT_Exp.Item , na.rm=T)/sqrt(length(RRT_Exp.Item [!is.na(RRT_Exp.Item)])))%>%ungroup
ggplot(synt_adaptation_plot, aes(Exp.Item.TRIAL, mean, group = Ambiguity, colour = Ambiguity, fill = Ambiguity, shape = Ambiguity, linetype = Ambiguity)) + geom_point() + guides(fill=FALSE) + geom_smooth(method = lm, formula = y ~  log(x)) + labs(x = 'Experimental item trial', y = 'Log RTs corrected for length and order(ms)', colour = 'Ambiguity', shape = 'Ambiguity', linetype = 'Ambiguity')

## 3.4.2 Stroop by Ambiguity interaction for full sentence RT
confl_adapt_plot<-lists_sentences%>%
  group_by(Ambiguity, Stroop)%>%
  summarise(N=length(RRT[!is.na(RRT)]),
            mean = mean(RRT, na.rm=T), sd = sd(RRT, na.rm=T),
            se= sd(RRT, na.rm=T)/sqrt(length(RRT[!is.na(RRT)])))%>%ungroup
confidence_intervals <- qt(0.95/2 + .5, confl_adapt_plot$N-1)
confl_adapt_plot$conf_int <- confl_adapt_plot$se * confidence_intervals
ggplot(confl_adapt_plot, aes(Stroop, mean, group = Ambiguity, colour = Ambiguity, fill = Ambiguity, shape = Ambiguity, linetype = Ambiguity)) + geom_point(position=position_dodge(0.05)) + geom_line(size=1.4) + geom_errorbar(aes(ymin=mean-conf_int, ymax=mean+conf_int), width=0.2,position=position_dodge(0.05)) + labs(x = 'Stroop trial type', y = 'Residual log RTs(ms)', colour = 'Ambiguity', shape = 'Ambiguity', linetype = 'Ambiguity')

## 3.4.3 Stroop by Ambiguity interaction for question accuracy
## Create df with question data only and filter out filler items
lists_questions<-lists_df%>%filter(Screen.Name=='Question')%>%filter(!(Condition=="X"))

stroop_amb_acc_plot<-lists_questions%>%
  group_by(Ambiguity, Stroop)%>%
  summarise(N=length(Correct[!is.na(Correct)]),
            mean = mean(Correct, na.rm=T), sd = sd(Correct, na.rm=T),
            se= sd(Correct, na.rm=T)/sqrt(length(Correct[!is.na(Correct)])))%>%ungroup
confidence_intervals <- qt(0.95/2 + .5, stroop_amb_acc_plot$N-1)
stroop_amb_acc_plot$conf_int <- stroop_amb_acc_plot$se * confidence_intervals
ggplot(stroop_amb_acc_plot, aes(Stroop, mean, group = Ambiguity, colour = Ambiguity, fill = Ambiguity, shape = Ambiguity, linetype = Ambiguity)) + geom_point(position=position_dodge(0.05)) + geom_line(size=1.4) + geom_errorbar(aes(ymin=mean-conf_int, ymax=mean+conf_int), width=0.2,position=position_dodge(0.05)) + labs(x = 'Stroop trial type', y = 'Residual log RTs(ms)', colour = 'Ambiguity', shape = 'Ambiguity', linetype = 'Ambiguity')


# 3.5 Stroop RT model --------------------------------------------------------------------------

## 3.5.1 create new df with only Stroop RTs
stroop_model<-lists_df%>% filter(Screen.Name=="Stroop")%>% mutate(Timed.Out=replace_na(Timed.Out,0))%>%filter(!(Timed.Out=='1'))


## 3.5.2 Define function to centre around mean to reduce collinearity (used for TRIAL and exp. item trial variables for all models)
c. <- function (x) scale(x, scale = FALSE)


## 3.5.3 Set contrasts
stroop_model$Stroop<-factor(stroop_model$Stroop)
contrasts(stroop_model$Stroop) <- contr.sum
contrasts(stroop_model$Stroop)

## 3.5.4 Run model
model1 <- lmer(Reaction.Time ~ Stroop+c.(log(TRIAL))+(1+Stroop| Participant.Private.ID)+(1|StroopStimulus), stroop_model, control = lmerControl(optCtrl = list(maxfun = 1e5)))
summary(model1)

# 3.6 Full sentence RRT model --------------------------------------------------------------------------
## 3.6.1 Set contrasts
lists_sentences$Ambiguity <- factor(lists_sentences$Ambiguity)
contrasts(lists_sentences$Ambiguity) <- "contr.sum"
contrasts(lists_sentences$Ambiguity)

contrasts(lists_sentences$Stroop) <- contr.sum
contrasts(lists_sentences$Stroop)

## 3.6.2 Run model

model1 <- lmer(RRT ~ Ambiguity*Stroop*c.(Exp.Item.TRIAL)+c.(log(TRIAL)) +(1| Participant.Private.ID) + (1+Ambiguity| Item), lists_sentences, control = lmerControl(optCtrl = list(maxfun = 1e5)))
summary(model1)

## 3.6.3 simple main effect analysis
test(emtrends(model1, pairwise ~Ambiguity, var='Exp.Item.TRIAL',pbkrtest.limit = 7022))

# 3.7 Accuracy model --------------------------------------------------------------------------

## 3.7.1 Set 'correct' and 'QT' as factor 
lists_questions$Correct<-as.factor(lists_questions$Correct)
lists_questions$QT<-as.factor(lists_questions$QT)

## 3.7.2 Set contrast
lists_questions$Ambiguity<-factor(lists_questions$Ambiguity)
contrasts(lists_questions$Ambiguity) <- contr.sum
contrasts(lists_questions$Ambiguity)

contrasts(lists_questions$Stroop) <- contr.sum
contrasts(lists_questions$Stroop)

contrasts(lists_questions$QT) <- contr.sum
contrasts(lists_questions$QT)

## 3.7.3 Run model
model1 <- glmer(Correct ~ Ambiguity*Stroop*QT*c.(Exp.Item.TRIAL)+(1+QT| Participant.Private.ID)+(1+Ambiguity+QT| Item), lists_questions, family=binomial, glmerControl(optimizer = "bobyqa", optCtrl = list(maxfun = 100000))) 
summary(model1)

# 3.8 Correlation between Stroop and ambiguity effects  --------------------------------------------------------------------------

## 3.8.1 load practice Stroop file
practice_stroop <- read.csv("~practice_stroop_exp3.csv", header = TRUE)
practice_stroop$Reaction.Time<-as.numeric(practice_stroop$Reaction.Time)
practice_stroop$Participant.Private.ID<-as.factor(practice_stroop$Participant.Private.ID)

## 3.8.2 exclude unnecessary rows (fixation, instructions etc), colour patch trials and timed out trials
practice_stroop<-practice_stroop%>%filter((Screen.Name=="Stroop")&(Trial.Type=='StroopPractice')&(Timed.Out=="0"))

## 3.8.3 calculate average ambiguity effect
ambig_effect<-lists_sentences%>%group_by(Participant.Private.ID)%>%
  summarise(amb_effect=mean(RRT[Ambiguity=='Amb'])-mean(RRT[Ambiguity=='Unamb']))%>%
  subset(select=c('Participant.Private.ID','amb_effect'))%>%ungroup()

## 3.8.4 calculate average Stroop effect
stroop_effect<-practice_stroop%>%group_by(Participant.Private.ID)%>%
  summarise(stroop_effect=mean(Reaction.Time[Trial.Condition=='I'])-mean(Reaction.Time[Trial.Condition=='C']))%>%
  subset(select=c('Participant.Private.ID','stroop_effect'))%>%ungroup()

## 3.8.5 merge the two dataframes and exclude any 'NA' for ambiguity_eff - these will be the same ones excluded from main dataframe
#excludes ones extra participant (3232525) from main analysis as alltrials were timed out (therefore NA for Stroop effect)
correlation<-stroop_effect%>%left_join(ambig_effect, by='Participant.Private.ID')%>% na.exclude

## 3.8.6 perform correlation
cor.test(correlation$amb_effect,correlation$stroop_effect)

## 3.8.7 calculate mean and SD for each effect
sd(correlation$amb_effect)
mean(correlation$amb_effect)

sd(correlation$stroop_effect)
mean(correlation$stroop_effect)

#### 4. Experiment 4 ####
rm(list=ls())
#load raw dataset
raw_data_exp4 <- read.csv("~raw_data_exp4.csv", header = TRUE)

# 4.1 Clean up data set --------------------------------------------------------------------------

## 4.1.1set correct variable types
cols<-c('Participant.Private.ID','Spreadsheet','Screen.Name','Attempt','Condition','Item','Ambiguity','Stroop','StroopStimulus' )
raw_data_exp4[cols]<-lapply(raw_data_exp4[cols],as.factor)

cols<-c('Reaction.Time','Correct','TRIAL','Exp.Item.TRIAL')
raw_data_exp4[cols]<-lapply(raw_data_exp4[cols], as.numeric)


##4.1.2exclude first word of every sentence:
lists_df<-filter(raw_data_exp4,!(Screen.Name=='Sentence'& Attempt=='1'))


# 4.2 Perform the necessary exclusions  --------------------------------------------------------------------------

## 4.2.1 exclude participants who scored <80% (rounded to nearest %) on Stroop trials and filler comp. questions
lists_over80<-lists_df%>% group_by(Participant.Private.ID,Screen.Name)%>%mutate(mean_corr=mean(Correct))%>%ungroup()%>% group_by(Participant.Private.ID)%>%
  filter(!any(Screen.Name=='Stroop'& mean_corr<0.795))%>%ungroup()%>%group_by(Participant.Private.ID,Screen.Name,Condition)%>%
  mutate(mean_corr=mean(Correct))%>%ungroup()%>%group_by(Participant.Private.ID)%>%
  filter(!any(Screen.Name=='Question'&Condition=='X'&mean_corr<0.795))%>%ungroup()%>% subset(select= -mean_corr)
### calculate number of participants excluded
length(unique(lists_df$Participant.Private.ID))-length(unique(lists_over80$Participant.Private.ID))
### transform into main df
lists_df<-lists_over80
rm(lists_over80)
### calculate number of participants per list
aggregate(lists_df$Participant.Private.ID,list(value = lists_df$Spreadsheet), function(x) length(unique(x)))

## 4.2.2 Exclude sentences with total RT>20000 ms ('Content End' gives us cumulative RT for the whole sentence)
lists_nolongsentences<-lists_df%>%group_by(Participant.Private.ID,Item)%>%filter(!any(Response=='Content End'&Reaction.Time>20000))%>%(ungroup)
### calculate number of trials excluded
sum(lists_df$Response=='Content End')-sum(lists_nolongsentences$Response=='Content End')
### calculate % of trials excluded
(sum(lists_df$Response=='Content End')-sum(lists_nolongsentences$Response=='Content End'))/sum(lists_df$Response=='Content End')*100
### filter out 'Content End' RT & transform into main df
lists_df<-lists_nolongsentences%>%filter(!(Response=='Content End'))
rm(lists_nolongsentences)

## 4.2.3 Exclude words with RTs >100ms and <2000ms
lists_noshortlongwords <- filter(lists_df, !((lists_df$Screen.Name=="Sentence" & lists_df$Reaction.Time<100)|(lists_df$Screen.Name=="Sentence" & lists_df$Reaction.Time>2000.0000)))
###calculate % of words excluded
((sum(lists_df$Screen.Name=='Sentence') - sum(lists_noshortlongwords$Screen.Name=='Sentence'))/sum(lists_df$Screen.Name=='Sentence'))*100
### transform into main df
lists_df <- lists_noshortlongwords 
rm(lists_noshortlongwords)

# 4.3 Create new variable 'region' for sentence regions --------------------------------------------------------------------------
lists_df$region <- ifelse(lists_df$Attempt %in% c("2", "3"), 'Subject', 
                          ifelse(lists_df$Attempt %in% c("4") & lists_df$Condition %in% c("B", "D"), 'Relativizer', 
                                 ifelse(lists_df$Attempt %in% c(  "5", "6", "7") &  lists_df$Condition %in% c("B", "D"), 'Ambig Region', 
                                        ifelse(lists_df$Attempt %in% c("4", "5", "6") & lists_df$Condition  %in% c("A", "C"), 'Ambig Region', 
                                               ifelse(lists_df$Attempt %in% c("8", "9") & lists_df$Condition %in% c("B","D"), 'Disambig Region', 
                                                      ifelse(lists_df$Attempt %in% c("7", "8") & lists_df$Condition %in% c("A", "C"), 'Disambig Region', 
                                                             ifelse(lists_df$Attempt %in% c("10") & lists_df$Condition %in% c("B", "D"), 'Spill', 
                                                                    ifelse(lists_df$Attempt %in% c("9") & lists_df$Condition %in% c("A", "C"), 'Spill', 'other'))))))))

lists_df$region <- as.factor(lists_df$region)

# 4.4 Create RRT and then exclude the fillers --------------------------------------------------------------------------

## 4.4.1 calculate residual reading times (RRTs): regress log RTs over Nchar with linear mixed effects regression
### create new variable 'nchar'(number of characters) for all words (exp +fillers)
lists_df$LetterNumbers <- nchar(lists_df$Response, type="chars", allowNA=FALSE)

### create new df with sentences only (exclude question and Stroop)
lists_sentences <- filter(lists_df, (lists_df$Screen.Name=="Sentence"))

### run RlogRT model
RRT_model <- lmer(log(Reaction.Time) ~ scale(LetterNumbers) + (1+scale(LetterNumbers)|Participant.Private.ID), lists_sentences)
lists_sentences$RRT <- residuals(RRT_model)

## 4.4.2 Exclude Filler
lists_sentences <- filter(lists_sentences, !((lists_sentences$Condition=="X")))


# 4.5 Graphs --------------------------------------------------------------------------

## 4.5.1 Stroop by Ambiguity interaction at disambiguating region
disambig_reg_plot<-lists_sentences%>%filter(region=='Disambig Region')%>%
  group_by(Ambiguity, Stroop)%>%
  summarise(N=length(RRT[!is.na(RRT)]),
            mean = mean(RRT, na.rm=T), sd = sd(RRT, na.rm=T),
            se= sd(RRT, na.rm=T)/sqrt(length(RRT[!is.na(RRT)])))%>%ungroup
confidence_intervals <- qt(0.95/2 + .5, disambig_reg_plot$N-1)
disambig_reg_plot$conf_int <- disambig_reg_plot$se * confidence_intervals
ggplot(disambig_reg_plot, aes(Stroop, mean, group = Ambiguity, colour = Ambiguity, fill = Ambiguity, shape = Ambiguity, linetype = Ambiguity)) + geom_point(position=position_dodge(0.05)) + geom_line(size=1.4) + geom_errorbar(aes(ymin=mean-conf_int, ymax=mean+conf_int), width=0.2,position=position_dodge(0.05)) + labs(x = 'Stroop trial type', y = 'Residual log RTs(ms)', colour = 'Ambiguity', shape = 'Ambiguity', linetype = 'Ambiguity')

## 4.5.2 Ambiguity by Experimental item trial interaction for question accuracy
## Create df with question data only and filter out filler items
lists_questions<-lists_df%>%filter(Screen.Name=='Question')%>%filter(!(Condition=="X"))

exp_amb_acc_plot<-lists_questions%>%
  group_by(Ambiguity, Exp.Item.TRIAL)%>%
  summarise(N=length(Correct[!is.na(Correct)]),
            mean = mean(Correct, na.rm=T), sd = sd(Correct, na.rm=T),
            se= sd(Correct, na.rm=T)/sqrt(length(Correct[!is.na(Correct)])))%>%ungroup()
ggplot(exp_amb_acc_plot, aes(Exp.Item.TRIAL, mean, group = Ambiguity, colour = Ambiguity, fill = Ambiguity, shape = Ambiguity, linetype = Ambiguity)) + geom_point() + guides(fill=FALSE) + geom_smooth(method=glm, formula = y ~  log(x)) + labs(x = 'number of items seen', y = '% accuracy', colour = 'Ambiguity', shape = 'Ambiguity' , linetype = 'Ambiguity') 

## 4.5.2 Stroop by Experimental item trial interaction for question accuracy
exp_stroop_acc_plot<-lists_questions%>%
  group_by(Exp.Item.TRIAL, Stroop)%>%
  summarise(N=length(Correct[!is.na(Correct)]),
            mean = mean(Correct, na.rm=T), sd = sd(Correct, na.rm=T),
            se= sd(Correct, na.rm=T)/sqrt(length(Correct[!is.na(Correct)])))%>%ungroup()
ggplot(exp_stroop_acc_plot, aes(Exp.Item.TRIAL, mean, group = Stroop, colour = Stroop, fill = Stroop, shape = Stroop, linetype = Stroop)) + geom_point() + guides(fill=FALSE) + geom_smooth(method=glm, formula = y ~  log(x)) + labs(x = 'number of items seen', y = '% accuracy', colour = 'Stroop', shape = 'Stroop' , linetype = 'Stroop') 


# 4.6 Stroop RT model --------------------------------------------------------------------------

## 4.6.1 create new df with only Stroop RTs
stroop_model<-lists_df%>% filter(Screen.Name=="Stroop")%>% dplyr::mutate(Timed.Out=replace_na(Timed.Out,0))%>%filter(!(Timed.Out=='1'))

## 4.6.2 Define function to centre around mean to reduce collinearity (used for TRIAL and exp. item trial variables for all models)
c. <- function (x) scale(x, scale = FALSE)

## 4.6.3 Set contrasts
stroop_model$Stroop<-factor(stroop_model$Stroop)
contrasts(stroop_model$Stroop) <- contr.sum
contrasts(stroop_model$Stroop)

## 4.6.4 Run model
model1 <- lmer(Reaction.Time ~ Stroop+c.(log(TRIAL))+(1+Stroop| Participant.Private.ID)+(1|StroopStimulus), stroop_model, control = lmerControl(optCtrl = list(maxfun = 1e5)))
summary(model1)

# 4.7 Ambiguous region RRT model --------------------------------------------------------------------------

## 4.7.1 create new df with mean RRTs for sub verb region
ambig_reg_corrected<-lists_sentences%>%filter(region=='Ambig Region')%>%
  group_by(Ambiguity, Stroop, Participant.Private.ID, Item, Exp.Item.TRIAL, TRIAL)%>%
  summarise(mean_corr_lrt = mean(RRT, na.rm=T))%>%ungroup()

## 4.7.2 Set contrasts
ambig_reg_corrected$Ambiguity <- factor(ambig_reg_corrected$Ambiguity)
contrasts(ambig_reg_corrected$Ambiguity) <- "contr.sum"
contrasts(ambig_reg_corrected$Ambiguity)

contrasts(ambig_reg_corrected$Stroop) <- "contr.sum"
contrasts(ambig_reg_corrected$Stroop)

## 4.7.3 Run model
model1 <- lmer(mean_corr_lrt ~ Ambiguity*Stroop*c.(Exp.Item.TRIAL)+c.(log(TRIAL))+(1+Ambiguity+Stroop| Participant.Private.ID) + (1+Ambiguity| Item), ambig_reg_corrected, control = lmerControl(optCtrl = list(maxfun = 1e5))) 
summary(model1)

# 4.8 Disambiguating region RRT model --------------------------------------------------------------------------

## 4.8.1 create new df with mean RRTs ambiguous region
disambig_reg_corrected<-lists_sentences%>%filter(region=='Disambig Region')%>%
  group_by(Ambiguity, Stroop, Participant.Private.ID, Item, Exp.Item.TRIAL, TRIAL)%>%
  summarise(mean_corr_lrt = mean(RRT, na.rm=T))%>%ungroup()

## 4.8.2 Set contrasts
disambig_reg_corrected$Ambiguity <- factor(disambig_reg_corrected$Ambiguity)
contrasts(disambig_reg_corrected$Ambiguity) <- "contr.sum"
contrasts(disambig_reg_corrected$Ambiguity)

contrasts(disambig_reg_corrected$Stroop) <- "contr.sum"
contrasts(disambig_reg_corrected$Stroop)

## 4.8.3 Run model
model1 <- lmer(mean_corr_lrt ~ Ambiguity*Stroop*c.(Exp.Item.TRIAL) + c.(log(TRIAL))+ (1+Ambiguity+Stroop| Participant.Private.ID) + (1| Item), disambig_reg_corrected, control = lmerControl(optCtrl = list(maxfun = 1e5)))
summary(model1)

# 4.9 Spill (last word) region RRT model --------------------------------------------------------------------------

## 4.9.1 create new df with mean RRTs ambiguous region
spill_reg_corrected<-lists_sentences%>%filter(region=='Spill')%>%
  group_by(Ambiguity, Stroop, Participant.Private.ID, Item, Exp.Item.TRIAL, TRIAL)%>%
  summarise(mean_corr_lrt = mean(RRT, na.rm=T))%>%ungroup()

## 4.9.2 Set contrasts
spill_reg_corrected$Ambiguity <- factor(spill_reg_corrected$Ambiguity)
contrasts(spill_reg_corrected$Ambiguity) <- "contr.sum"
contrasts(spill_reg_corrected$Ambiguity)

contrasts(spill_reg_corrected$Stroop) <- "contr.sum"
contrasts(spill_reg_corrected$Stroop)

## 4.9.3 Run model
model1 <- lmer(mean_corr_lrt ~ Ambiguity*Stroop*c.(Exp.Item.TRIAL) + c.(log(TRIAL))+ (1+Stroop| Participant.Private.ID) + (1+Stroop| Item), spill_reg_corrected, control = lmerControl(optCtrl = list(maxfun = 1e5))) 
summary(model1)

# 4.10 Accuracy model --------------------------------------------------------------------------

## 4.10.1 Set 'correct' as factor
lists_questions$Correct<-as.factor(lists_questions$Correct)

## 4.10.2 Set contrasts
lists_questions$Ambiguity<-factor(lists_questions$Ambiguity)
contrasts(lists_questions$Ambiguity) <- "contr.sum"
contrasts(lists_questions$Ambiguity)

contrasts(lists_questions$Stroop) <- "contr.sum"
contrasts(lists_questions$Stroop)


## 4.10.3 Run model
model1 <- glmer(Correct ~ Ambiguity*Stroop*c.(Exp.Item.TRIAL)+(1+Ambiguity| Participant.Private.ID)+(1+Ambiguity| Item), lists_questions, family=binomial, glmerControl(optimizer = "bobyqa", optCtrl = list(maxfun = 100000))) 
summary(model1)

## 4.10.4 Simple main effects analysis
test(emtrends(model1, pairwise ~Ambiguity|Stroop, var='Exp.Item.TRIAL'))

# 4.11 Correlation between Stroop and ambiguity effects  --------------------------------------------------------------------------

## 4.11.1 load practice Stroop file
practice_stroop <- read.csv("~practice_stroop_exp4.csv", header = TRUE)
practice_stroop$Reaction.Time<-as.numeric(practice_stroop$Reaction.Time)
practice_stroop$Participant.Private.ID<-as.factor(practice_stroop$Participant.Private.ID)

## 4.11.2 exclude unnecessary rows (fixation, instructions etc), colour patch trials and timed out trials
practice_stroop<-practice_stroop%>%filter((Screen.Name=="Stroop")&(Trial.Type=='StroopPractice')&(Timed.Out=="0"))

## 4.11.3 calculate average ambiguity effect
disambig_reg_effect<-lists_sentences%>%filter(region=='Disambig Region')%>%group_by(Participant.Private.ID)%>%
  summarise(amb_effect=mean(RRT[Ambiguity=='A'])-mean(RRT[Ambiguity=='U']))%>%
  subset(select=c('Participant.Private.ID','amb_effect'))%>%ungroup()

## 4.11.4 calculate average Stroop effect
stroop_effect<-practice_stroop%>%group_by(Participant.Private.ID)%>%
  summarise(stroop_effect=mean(Reaction.Time[Trial.Condition=='I'])-mean(Reaction.Time[Trial.Condition=='C']))%>%
  subset(select=c('Participant.Private.ID','stroop_effect'))%>%ungroup()

## 2.11.5 merge the two dataframes and exclude any 'NA' for ambiguity_eff - these will be the same ones excluded from main dataframe
#excludes ones extra participant (3232525) from main analysis as alltrials were timed out (therefore NA for Stroop effect)
correlation<-stroop_effect%>%left_join(disambig_reg_effect, by='Participant.Private.ID')%>% na.exclude

## 2.11.6 perform correlation
cor.test(correlation$amb_effect,correlation$stroop_effect)

## 2.11.7 calculate mean and SD for each effect
sd(correlation$amb_effect)
mean(correlation$amb_effect)

sd(correlation$stroop_effect)
mean(correlation$stroop_effect)
